require 'test_helper'

class BookTest < ActiveSupport::TestCase
	test "book attributes must not be empty" do
		book = Book.new
		assert book.invalid?
		assert book.errors[:title].any?
		assert book.errors[:description].any?
		assert book.errors[:price].any?
		assert book.errors[:image].any?
	end
	test "book price must be positive" do
		book = Book.new(title: "Title 1",
						description: "description test", 
						image: "test.jpg")
		book.price = -1
		assert book.invalid?
		assert_equal ["must be greater than or equal to 0.01"], book.errors[:price]
		book.price = 0
		assert book.invalid?
		assert_equal ["must be greater than or equal to 0.01"], book.errors[:price]
		book.price = 1
		assert book.valid?
	end
	def new_book(image) 
		Book.new(title: "Title 1",
				description: "description test", 
				price: 1, 
				image: image)
	end
	test "image" do
		ok = %w{ test.gif test.jpg test.png TEST.JPG TEST.Jpg http://p.r.o/v/a/test.png }
		bad = %w{ test.doc test.png/more test.jpg.more } 
		ok.each do |name|
			assert new_book(name).valid?, "#{name} should be valid"
		end
		bad.each do |name|
			assert new_book(name).invalid?, "#{name} shouldn't be valid"
		end
	end
end
